.. redirect-from:: /users/github_stats

.. _github-stats:

GitHub statistics for 3.11.0 (Apr 24, 2026)
===========================================

GitHub statistics for 2024/12/14 (tag: v3.10.0) - 2026/04/24

These lists are automatically generated, and may be incomplete or contain duplicates.

We closed 246 issues and merged 764 pull requests.
The full list can be seen `on GitHub <https://github.com/matplotlib/matplotlib/milestone/96?closed=1>`__

The following 264 authors contributed 4590 commits.

* 34j
* Aaratrika-Shelly
* Aaron Meurer
* Aasma Gupta
* Abhiroop Batabyal
* Abitamim Bharmal
* Adam Ormondroyd
* AdamOrmondroyd
* Aditya Singh
* aditya-singh597
* AdrashDec
* Aishling Cooke
* Alan Burlot
* Albert Y. Shih
* ALBIN BABU VARGHESE
* albus-droid
* Alexandra Khoo
* Allison
* alphanoobie
* Aman Kushwaha
* AMAN KUSHWAHA
* Aman Nijjar
* Aman Parganiha
* Aman Srivastava
* Amisha Mehta
* amishamehta99
* Amitesh Singh
* Anabelle VanDenburgh
* Andrea Alberti
* Andres Gutierrrez
* Andrew Landau
* Andrés Gutierrez
* Anselm Hahn
* anTon
* Anton
* Antony Lee
* Archil Jain
* Arnaud Patard
* Barbier--Darnal Joseph
* beelauuu
* Ben Greiner
* Ben Root
* Bodhi Silberling
* Brian Christian
* BriAnna Foreman
* brk
* Carlos Ramos Carreño
* Cemonix
* Chaoyi Hu
* Charlie Thornton
* Chirag Sharma
* Chirag3841
* chrisjbillington
* Christine P. Chai
* clairefio
* Clemens Brunner
* Clément Robert
* cmp0xff
* Colton Lathrop
* Constantinos Menelaou
* Corenthin ZOZOR
* cvanelteren
* Daniel Weiss
* Danny
* David Lowry-Duda
* David Stansby
* dependabot[bot]
* DerWeh
* Diksha
* Dominik Stiller
* Doron Behar
* Duncan Macleod
* DWesl
* Edge-Seven
* ee25b003
* ellie
* Elliott Sales de Andrade
* Emmanuel Ferdman
* EncryptedDoom
* Eric Firing
* Eric Larson
* Evgenii Radchenko
* Eytan Adler
* Fazeel Usmani
* founta
* francisayyad03
* Francisco Cardozo
* G Karthik Koundinya
* G\. D\. McBain
* G26Karthik
* ganglike
* Geoffrey Thomas
* Gguidini
* Greg Lucas
* guillermodotn
* hannah
* Hannan7812
* Hasan Rashid
* Hassan Kibirige
* heinrich5991
* hu-xiaonan
* Husain Gadiwala
* Ian Hunt-Isaak
* Ian Thomas
* ianlv
* IdiotCoffee
* ilakk manoharan
* Ilakkuvaselvi Manoharan
* intelliking
* Inês Cachola
* ishan372or
* James Addison
* Javier Pérez Robles
* jaya prajapati
* jayaprajapatii
* Jaylon
* Jimmy Shah
* jocelynvj
* JOD
* joddeepesh-cloud
* Jody Klymak
* Johannes Kopton
* Jonas Drotleff
* Jonathan Reimer
* Jouni K. Seppänen
* Julian Chen
* Kaustbh
* Kaustubh
* kdpenner
* Khushi_29
* Khushikela29
* KIU Shueng Chuan
* konmenel
* Kris Rubiano
* kusch lionel
* Kyle Martin
* Kyle Sunden
* Kyra Cho
* landoskape
* LangQi99
* Larry Bradley
* leakyH
* Leo Singer
* Leon Merten Lohse
* lilfer
* litchi
* Logan Pageler
* Logan-Pageler
* Lucas Gruwez
* Lucx33
* Luka Aladashvili
* Lukas Hergt
* lukashergt
* Lumberbot (aka Jack)
* Lívia Lutz
* m-sahare
* Mafalda Botelho
* Manit Roy
* manit2004
* Manthan Nagvekar
* marbled-toast
* Marco Barbosa
* Marco Gorelli
* Marie
* Marten H. van Kerkwijk
* Marten Henric van Kerkwijk
* martincornejo
* masih.khatibzdeh
* Mateusz Sokół
* Matthew Feickert
* Melissa Weber Mendonça
* Melwyn Francis Carlo
* MengAiDev
* Milan Gittler
* MiniX16
* Miriam
* Miriam Simone
* miriamsimone
* MKhatibzadeh
* Mohit Pal
* Moniza Kidwai
* MQY
* mromanie
* Muhammad Hannan Akram
* musvaage
* N R Navaneet
* NabeelShar
* nakano
* Nathan G. Wiseman
* Nathan Goldbaum
* Nathan Hansen
* Nathan McDougall
* Nick Coish
* Nicolai Weitkemper
* Niklas Mertsch
* null-dreams
* Obliman
* Oscar Gustafsson
* Owl
* Parsa Homayouni
* Patrick Seitz
* Pedro Marques
* pedrom2002
* Pieter Eendebak
* Pirzada Ahmad Faraz
* pirzada-ahmadfaraz
* Praful Gulani
* Pranav
* Pranav Raghu
* pre-commit-ci[bot]
* proximalf
* q33566
* Qian Zhang
* r3kste
* Rafael Katri
* Rahul
* Rahul Monani
* Raphael Erik Hviding
* Raphael Quast
* RETHICK CB
* RogueRebel33
* Roman
* Roman A
* Ruth Comer
* ruvilonix
* Ryan May
* Saakshi Gupta
* Sai Chaitanya, Sanivada
* saikarna913
* Sanchit Rishi
* Saumya
* Scott Shambaugh
* Sebastien Wieckowski
* Siddharth_Savani
* Sonu Singh
* star1327p
* statxc
* Stefan van der Walt
* Stefan Vujadinovic
* Steve Berardi
* Steve Nicholson
* tfpf
* Thomas A Caswell
* thomashopkins32
* Tiago Marques
* Tim Heap
* Tim Hoffmann
* Timon Erhart
* Tine Zivic
* Tingwei Zhu
* Trygve Magnus Ræder
* Ubuntu
* Vagner Messias
* Vedant Madane
* Victor Liu
* Vidya
* Vikash Kumar
* Vishal Pankaj Chandratreya
* Vraj Rajpura
* Weh Andreas
* Wiliam
* Yuepeng Gu
* Zhongqi LUO
* ZPyrolink

GitHub issues and pull requests:

Pull Requests (764):

* :ghpull:`31561`: Fixed bug with an uninitialized colormap in parallel threads
* :ghpull:`31555`: FIX: removing colorbar's axes also removes colorbar
* :ghpull:`31560`: merge up v3.10.9
* :ghpull:`31416`: MNT: Privatize Formatter attributes
* :ghpull:`23616`: feat(mathtext): support underline
* :ghpull:`31554`: BUG: avoid a deprecation warning from numpy 2.5 (calling ``datetime64('NaT')`` without a unit is deprecated)
* :ghpull:`31535`: DOC: fix broken link to wxPython Widget Inspection Tool
* :ghpull:`31551`: Bump https://github.com/pre-commit/mirrors-mypy from v1.20.1 to 1.20.2
* :ghpull:`31552`: Bump scientific-python/upload-nightly-action from 0.6.3 to 0.6.4 in the actions group
* :ghpull:`31478`: Fix errorbar autoscaling inconsistency on log axes
* :ghpull:`31522`: MNT: Update all pre-commit hooks
* :ghpull:`31365`: Add thumbnail for embedding in user interfaces examples
* :ghpull:`31530`: BUG: Fix relim() to support Collection artists (scatter, etc.)
* :ghpull:`31514`: Add suggestions to more lookup errors
* :ghpull:`31465`: lib/matplotlib/tests/test_inset.py: Fix tolerance on aarch64
* :ghpull:`31521`: Drop support for font hinting factor
* :ghpull:`31492`: MNT: Ensure all types from matplotlib.typing are documented
* :ghpull:`31524`: FIX: Disallow twinx/twiny on Axes3D
* :ghpull:`31540`: DOC: replace dolphin license RDF block with prose attribution
* :ghpull:`31426`: Fix: Optimize Cursor clearing on mouse exit to prevent lag
* :ghpull:`31512`: Document that ``TimedAnimation`` should not be used
* :ghpull:`31518`: DOC: add tags to tick locator and formatter examples
* :ghpull:`31519`: Bump the actions group with 3 updates
* :ghpull:`31517`: [DOC] make headers in pie example consistent
* :ghpull:`31515`: Remove unnecessary ruff lint exceptions
* :ghpull:`31516`: TST: account for flakiness with Numpy v1 (part 3)
* :ghpull:`31489`: Fixed: specified exception type in cbook.py
* :ghpull:`31314`: DOC: setting active axes position is ineffective
* :ghpull:`31148`: TST: Use explicit style in all image_comparison calls
* :ghpull:`31486`: ENH: Add an environment variable to ignore system fonts
* :ghpull:`31507`: PR template: always ask for AI declaration
* :ghpull:`31503`: TST: Harden handling of Popen subprocesses
* :ghpull:`31490`: DOC: Minor style improvement of radio buttons examples
* :ghpull:`31181`: ENH: Give control whether twinx() or twiny() overlays the main axis
* :ghpull:`31485`: MNT: Update bundled font libraries
* :ghpull:`31484`: MNT: Use new defaults in set_font_settings_for_testing
* :ghpull:`31483`: Bump the actions group across 1 directory with 2 updates
* :ghpull:`31476`: DOC: Improve Radio Buttons example
* :ghpull:`31275`: DOC: use minigallery for tutorial thumbnails
* :ghpull:`29763`: Shorten Agg template usage with class template argument deduction.
* :ghpull:`31353`: Fix #21409: Make twin axes inherit parent position
* :ghpull:`31431`: FIX: Guard against already-removed labels in ContourSet.remove()
* :ghpull:`31428`: Relax type hints for xy and xytext in annotate
* :ghpull:`31468`: DOC: Replace ``skip_deprecated`` extension by standard Sphinx metadata
* :ghpull:`30161`: Font and text overhaul
* :ghpull:`31461`: Support font features/language in default RendererBase.draw_text
* :ghpull:`31303`: TST: Reset tolerances on tests changed by text overhaul
* :ghpull:`31471`: DOC: Use FuncAnimation in 3D animations
* :ghpull:`31477`: DOC: Improve Radio Buttons Grid example
* :ghpull:`31470`: MNT: Deprecate matplotlib.image.thumbnail
* :ghpull:`31475`: Purge gitter links
* :ghpull:`31466`: DOC: make simple animation example easier to find
* :ghpull:`31469`: Change if condition to allow handles to be passed as a ndarray and not only Python list or tuple, etc.
* :ghpull:`31459`: DOC: Improve AI policy
* :ghpull:`31444`: Bump the actions group with 3 updates
* :ghpull:`31456`: Clarify fonttype switch in backend_pdf.
* :ghpull:`31300`: TST: Set tests touched by text overhaul to mpl20 style
* :ghpull:`31449`: Fix: improve log-scale error message wording
* :ghpull:`30385`: Add type stubs for functions in matplotlib.dates
* :ghpull:`31442`: TST: account for flakiness with Numpy v1 (part 2)
* :ghpull:`31440`: Fix FreeType runtime version check
* :ghpull:`31295`: TST: Cleanup back-compat code in tests touched by text overhaul
* :ghpull:`31408`: Merge branch 'main' into text-overhaul
* :ghpull:`31407`: BLD: Update bundled FreeType to 2.14.3
* :ghpull:`31439`: Clarify SecondaryAxes limit behavior via documentation
* :ghpull:`31432`: DOC: More concise page title: Development setup
* :ghpull:`31423`: DOC: Remove pyplot vs. OO interface discussion from lifecycle example
* :ghpull:`31413`: ENH: Support partial figsize with None (#31400)
* :ghpull:`31368`: Fix: Prevent Cursor blitting from erasing overlapping axes (#25670)
* :ghpull:`31409`: Bump the actions group with 2 updates
* :ghpull:`31417`: DOC: Explain return value of secondary_x/yaxis
* :ghpull:`31412`: MNT: Minor cleanup of label formatting in PathCollection.legend_elements
* :ghpull:`31422`: Improve legend loc and bbox_to_anchor documentation (#26620)
* :ghpull:`31414`: DOC: Improve Formatter documentation
* :ghpull:`31419`: Add a short example to StrMethodFormatter docstring
* :ghpull:`31405`: Tweak secondary_{x,y}axis docs.
* :ghpull:`31372`: BLD: Update bundled libraqm to 0.10.4
* :ghpull:`31198`: Allow tuning the shape of {L,R,D}Arrow tips.
* :ghpull:`31183`: ENH: Allow fonts to be addressed by any of their SFNT family names
* :ghpull:`31371`: ps/pdf: Override font height metrics to support AFM files
* :ghpull:`31343`: TST: Restore some tolerances for some arch/platform-specific failures
* :ghpull:`31248`: SEC: Remove eval() from validate_cycler
* :ghpull:`31395`: doc: mention ``bar_label`` in ``bar`` and ``barh``
* :ghpull:`31385`: Make font search case insensitive in logo example
* :ghpull:`31399`: DOC: Rename gallery README.txt files to GALLERY_HEADER.rst
* :ghpull:`29998`: Implement head resizing (and reversal) for larrow/rarrow/darrow
* :ghpull:`24744`: Addresses issue #24618 "Road sign" boxstyle/annotation, alternative to #24697
* :ghpull:`31392`: Tweak Formatter method docstrings.
* :ghpull:`31200`: DOC: moderation and enforcement
* :ghpull:`30513`: TST: Remove redundant font tests
* :ghpull:`31363`: Update black requirement from <26 to <27
* :ghpull:`31355`: Bump the actions group across 1 directory with 8 updates
* :ghpull:`31370`: Update dead link for Ware 1988 in colormap docs
* :ghpull:`31357`: ci: Configure dependabot to skip minver requirements
* :ghpull:`31358`: TST: Replace pywin32 with ctypes wrapper
* :ghpull:`29281`: Port requirements to PEP735
* :ghpull:`31347`: FIX: Deprecate using clabel() with filled contours
* :ghpull:`31349`: DOC: Correct a few typos in documentation
* :ghpull:`31244`: PERF: Sticky edges speedup
* :ghpull:`31306`: [MNT]: Implement ``Scale.val_in_range`` and refactor ``_point_in_data_domain``
* :ghpull:`31291`: text: Use font metrics to determine line heights
* :ghpull:`30900`: Added Turbo License doc
* :ghpull:`31307`: FIX: avoid applying dashed patterns to zero-width lines and patches
* :ghpull:`31338`: MAINT: Fix formatting on autoclose bot message
* :ghpull:`31313`: Fixed lingering bugs with image rendering related to exact half display pixels
* :ghpull:`31329`: DOC: Add note about opening multiple PRs
* :ghpull:`29093`: Add wasm CI
* :ghpull:`31283`: MNT: Add autoclose bot inspired by scikit-learn
* :ghpull:`31322`: DOC: fix pcolormesh doc
* :ghpull:`31308`: DOC: Add thumbnail for multipage_pdf gallery example
* :ghpull:`31315`: [BUG] Warn when legend() receives mismatched handles and labels in 2-argument positional form
* :ghpull:`31251`: Emit xlim_changed / ylim_changed when limits expand via set_xticks / set_yticks
* :ghpull:`31316`: DOC: clarify explanation of axline in infinite lines example
* :ghpull:`31309`: DOC: update pandas intersphinx mapping
* :ghpull:`31281`: Drop axis_artist tickdir image compat, due to text-overhaul merge.
* :ghpull:`31294`: MNT: Restrict webagg toolbar actions to valid actions
* :ghpull:`31282`: SEC: Block shell escapes in latex and ps commands
* :ghpull:`31252`: DOC: Fix rendering of quiver documentation
* :ghpull:`31285`: ENH: Ignore empty text for tightbbox
* :ghpull:`31230`: API: Raise ValueError in subplots if num refers to existing figure
* :ghpull:`31133`: fix: resolve FigureCanvasTkAgg clipping on Windows HiDPI
* :ghpull:`30908`: mathtext support for \phantom, \llap, \rlap for faking text metrics.
* :ghpull:`31261`: Bump the actions group with 2 updates
* :ghpull:`30369`: Support standard tickdir control (in/out/inout) in axisartist.
* :ghpull:`27987`: qhull: Fix inconsistent formatting function arguments
* :ghpull:`31061`: BUG: Fix text appearing far outside valid axis scale range
* :ghpull:`31117`: Clarify introductory description in scatter_star_poly example.
* :ghpull:`31203`: Fix Axes.hist crash for numpy timedelta64 inputs
* :ghpull:`31262`: DOC: Correct ``byweekday`` description in ``WeekdayLocator``
* :ghpull:`31260`: MNT: Raise NotImplementedError for 3D semilog plots
* :ghpull:`31143`: Deprecate public access to XMLWriter; simplify some attribute settings
* :ghpull:`31258`: DOC: Document that set_aspect applies the aspect lazily
* :ghpull:`31005`: PERF: Bezier root finding speedup
* :ghpull:`30980`: Fix 3D axes to properly support non-linear scales (log, symlog, etc.)
* :ghpull:`30844`: allow passing a function to ``CallbackRegistry.disconnect_func``
* :ghpull:`30995`: PERF: Speed up ticks processing when not visible or using a NullLocator
* :ghpull:`31128`: Fix relim() ignoring scatter PathCollection offsets
* :ghpull:`31166`: Add private Artist-level autoscale participation flag
* :ghpull:`31238`: CI: Explicitly define CI workflow permissions
* :ghpull:`31228`: Bump the actions group with 3 updates
* :ghpull:`29469`: MNT: Separate property cycle handling from _process_plot_var_args
* :ghpull:`31121`: mathtext: add mathnormal and distinguish between normal and italic family
* :ghpull:`31170`: Cleanup QuiverKey init and deprecate some attributes.
* :ghpull:`31004`: PERF: More speedups
* :ghpull:`31226`: ft2font: Read more entries from OS/2 font table
* :ghpull:`31191`: TST: Switch mathtext tests to mpl20
* :ghpull:`31231`: DOC: make nightly download command one line so it works on Windows
* :ghpull:`30754`: MNT: Improve Grouper
* :ghpull:`31236`: DOC: Remove gitter links and direct folks to Discourse chat
* :ghpull:`31145`: ENH: Snap 3D view angle changes when holding Control key
* :ghpull:`31179`: Remove mpl.text._get_textbox.
* :ghpull:`31202`: ENH: Adds ``errorbar.capthick`` and ``errorbar.elinewidth`` to mplstyle
* :ghpull:`31222`: DOC: Rewrite tickabel rotation example to use rotation_mode
* :ghpull:`31001`: PERF: Text handling speedups
* :ghpull:`30975`: Use LOCALAPPDATA for config/cache directories on Windows
* :ghpull:`30795`: Fix array alpha to multiply (not replace) existing RGBA alpha
* :ghpull:`31021`: Fixed inaccurate image placement and even more resampling bugs
* :ghpull:`31110`: mathtext: Fetch quad width & axis height from font metrics
* :ghpull:`31193`: DOC: Clarify computed_zorder applies to Collections and Patches only
* :ghpull:`31217`: DOC: use pivot='middle' instead of 'mid' in quiver demo
* :ghpull:`31212`: DOC: discourage pivot='mid' for quiver
* :ghpull:`31204`: Reword the "fully-new contributor" section.
* :ghpull:`31201`: DOC: Add sections to rcParams documentation
* :ghpull:`31196`: DOC: Document which files need to be updated for new rcparams
* :ghpull:`31163`: DOC: update new contributor guidance re timelines, AI, reaching out
* :ghpull:`31124`: MAINT: add AI disclosure to pr template
* :ghpull:`31076`: Avoid using pyplot for check_figures_equal
* :ghpull:`31189`: Bump the actions group with 2 updates
* :ghpull:`31188`: Remove use of the discouraged plt.imread() in the docs.
* :ghpull:`31007`: TST: Skip tests that use a large amount of memory by default
* :ghpull:`30967`: ENH: Implement gapcolor for patch edges
* :ghpull:`31142`: doc: explain that gfi is for training and add no AI policy
* :ghpull:`31137`: TST: Simplify image testing decorator calls
* :ghpull:`31119`: MNT: Normalize internal set_foreground calls to RGBA
* :ghpull:`31107`: Fix confusion between text height and ascent in metrics calculations.
* :ghpull:`31168`: Fix docstring ``lib/matplotlib/pyplot.py`` and related ``lib/matplotlib/__init__.py``
* :ghpull:`31167`: Copy-edit the transform tutorial.
* :ghpull:`31160`: Bump the actions group across 1 directory with 4 updates
* :ghpull:`29374`: DOC: Emphasize artist as annotation in AnnotationBbox demo and add to annotation guide
* :ghpull:`31151`: Add mlx support
* :ghpull:`31141`: Fix mutable default arguments in backend_svg.py
* :ghpull:`31140`: DOC: Document set_figure() is a low-level API
* :ghpull:`31026`: DOC: Explicitly prohibit bots/agents to post contents
* :ghpull:`31131`: MAINT: added don't solve AI note to gfi bot
* :ghpull:`31043`: MAINT: new contributor bot ask for AI usage
* :ghpull:`30803`: {Radio,Check}Buttons: Add 2D grid labels layout support
* :ghpull:`31111`: Remove some code for compatibility with pyparsing<3
* :ghpull:`31046`: Implement TeX's fraction and script alignment
* :ghpull:`31085`: Refactor RendererAgg.draw_{mathtext,text,tex} to use same base algorithm
* :ghpull:`28814`: patheffects.SimpleLineShadow calling non-existent get_foreground method from GraphicsContextBase
* :ghpull:`31090`: MAINT: Move to first-contribution action
* :ghpull:`31069`: Fix positioning of wide mathtext accents.
* :ghpull:`30938`: Update bundled FreeType and HarfBuzz libraries
* :ghpull:`31091`: BUG: Fix IndexLocator.tick_values returning values greater than vmax
* :ghpull:`31050`: ft2font: Extend OS/2 table with new fields
* :ghpull:`30039`: Rasterize dvi files without dvipng.
* :ghpull:`31081`: Switch from pre-commit to prek
* :ghpull:`30993`: PERF: Speed up log and symlog scale transforms
* :ghpull:`31082`: MNT: Rename check_getitem to getitem_checked
* :ghpull:`31080`: DOC: Fix missing references for updated FT2Font.set_text
* :ghpull:`30746`: Fix PDF bloat for off-axis scatter with per-point colors
* :ghpull:`31062`: Bump the actions group across 1 directory with 4 updates
* :ghpull:`31063`: Merge main back into text-overhaul branch
* :ghpull:`31056`: Keep mathtext boxes in xywh representation throughout.
* :ghpull:`31060`: MNT: Remove unused eventson context from artist property update
* :ghpull:`31059`: PERF: Refactor bezier poly coefficient calcs for speedup
* :ghpull:`31000`: PERF: Skip kwargs normalization in Artist._cm_set
* :ghpull:`31028`: DOC: Generate rcParams docs directly during build
* :ghpull:`31058`: TST: add basic test for set
* :ghpull:`31057`: DOC: Clarify Artist.set() behavior
* :ghpull:`31041`: Add tests for invalid properties and duplicate aliases in Artist.set
* :ghpull:`30978`: MNT: Discourage Artist.update
* :ghpull:`31016`: Doc: Clarify default levels behavior in contour/contourf
* :ghpull:`31031`: RadioButtons: fix self._clicked method (followup to #30997)
* :ghpull:`30059`: Drop the FT2Font intermediate buffer.
* :ghpull:`31013`: docs: improve contour docstring and wrap long lines
* :ghpull:`31044`: fix for sphinx_gallery < 0.16.0
* :ghpull:`31033`: Add type hint for fig_kw in subplots
* :ghpull:`31030`: DOC: bring the credits page a little more up-to-date
* :ghpull:`31034`: DOC: Make grammatical corrections to documentation
* :ghpull:`30752`: Improving error message for width and position type mismatch in violinplot
* :ghpull:`31023`: Speedup normalize_kwargs by storing aliases in a more practical format.
* :ghpull:`31014`: TST: Fix warnings from Pillow for unavailable features
* :ghpull:`30935`: FIX: Handle AxesWidget cleanup after failed init
* :ghpull:`31020`: DOC: Fix doc builds with Sphinx 9
* :ghpull:`31025`: DOC: move doc build options into tables and tabs
* :ghpull:`31024`: Fix formatting: add space after # in TODO comment
* :ghpull:`30997`: widgets: use a shared _Buttons class for {Radio,Check}Buttons
* :ghpull:`31010`: DOC: update and slightly reorg docs docs
* :ghpull:`31011`: Fix grammar: 'it would better' -> 'it would be better' in comment
* :ghpull:`31002`: Remove outdated notion of property alias priority from docs.
* :ghpull:`29881`: feat(CI): add Codecov Test Analytics for flaky and failed tests
* :ghpull:`30999`: Bump the actions group across 1 directory with 2 updates
* :ghpull:`30991`: Improve findfont cache invalidation.
* :ghpull:`30992`: Fix typo: remove extra space in MultiCursor deprecation message
* :ghpull:`30984`: DOC: update interactive rebase instructions
* :ghpull:`27946`: Add support for horizontal CheckButtons
* :ghpull:`30778`: MNT: remove decorator frames from traceback
* :ghpull:`30838`: Do not fail when markers are numpy integers
* :ghpull:`30977`: Revert exception handling case after numpy minver bump to 1.25
* :ghpull:`30849`: Fix Axes.grid() to respect alpha in color tuples
* :ghpull:`30939`: DOC: Improve widgets API documentation
* :ghpull:`30970`: DOC: Move spectral plot examples from lines to statistics
* :ghpull:`30945`: Prevent blitting errors after canvas swap in RadioButtons and CheckButtons
* :ghpull:`30184`: Fixed several accuracy bugs with image resampling
* :ghpull:`30973`: DOC: modernise barh example
* :ghpull:`30956`: DOC: Some small additions to the API docs
* :ghpull:`30959`: DOC: Clarify matplotlib vs. matplotlib-base in conda
* :ghpull:`30950`: TST: account for flakiness with Numpy v1
* :ghpull:`30954`: Fix trivial typo in example.
* :ghpull:`30947`: TST: always force the SETUPTOOLS_SCM version in test subprocesses
* :ghpull:`30949`: Add uv.lock to .gitignore
* :ghpull:`30948`: DOC: Improve linkage between rcParams-related documentation
* :ghpull:`30871`: Define the supported rcParams as code
* :ghpull:`30886`: BUG: Fix Windows subprocess timeouts with CREATE_NO_WINDOW flag
* :ghpull:`30777`: DOC: Introduce backend versions
* :ghpull:`30824`: Fixed bilinear interpolation for ``SegmentedBivarColormap``
* :ghpull:`30942`: Bump pypa/cibuildwheel from 3.3.0 to 3.3.1 in the actions group
* :ghpull:`30918`: TST: account for asyncio changes in py314
* :ghpull:`30937`: Merge branch 'v3.10.x' into main
* :ghpull:`30936`: DOC: Clarify data inputs for boxplot() and violinplot()
* :ghpull:`30855`: DOC: Clarify and unify set_linestyle
* :ghpull:`30921`: Exclude confirmed bugs from stale bot
* :ghpull:`30892`: Bump the actions group across 1 directory with 11 updates
* :ghpull:`30920`: FIX: Increase reruns for flaky test_invisible_Line_rendering (#30809)
* :ghpull:`30889`: MNT: Make transforms helper functions private
* :ghpull:`30922`: Reduce stale bot to run once per week
* :ghpull:`30912`: Pcolormesh Doc Fix
* :ghpull:`30916`: Docs: Remove outdated annotate_transform example, link to annotation tutorial
* :ghpull:`30919`: DOC: Correct typos on a/an usage including print messages
* :ghpull:`30914`: Fix outdated documentation links for violin/boxplot example
* :ghpull:`30907`: Inline intermediate constructs in axisartist demos.
* :ghpull:`30867`: Handle single color for multiple datasets in ``hist``
* :ghpull:`30591`: FIX: Make widget blitting compatible with swapped canvas
* :ghpull:`30821`: Implements the Okabe-Ito accessible colormap.
* :ghpull:`30737`: Deprecate unused canvas parameter to MultiCursor
* :ghpull:`29966`: Fix AxesWidgets on inset_axes that are outside their parent.
* :ghpull:`30600`: Implement warning for Text3D's rotation/rotation_mode parameters
* :ghpull:`30847`: Fix test_ensure_multivariate_data on 32-bit systems
* :ghpull:`30856`: DOC: Rectangle: Link to FancyBboxPatch for rounded corners
* :ghpull:`30854`: DOC: Improve docs of legend loc=best
* :ghpull:`30863`: Fix macOS toolbar crash
* :ghpull:`30853`: Minor doc fixes re: close()ing figures.
* :ghpull:`30846`: Add pixi and uv install options to bug template
* :ghpull:`30842`: Update release docs for new publish workflow, remove old publish step
* :ghpull:`30841`: Add type annotation for LocationEvent.modifiers
* :ghpull:`30775`: FIX: figureoptions updates title string only
* :ghpull:`30726`: Enh/Add hatch pattern support to Axes.grouped_bar
* :ghpull:`30808`: Consolidate style parameter handling for plotting methods that call other plotting methods
* :ghpull:`30815`: MNT: Fix handling of ints in rgb_to_hsv()
* :ghpull:`30533`: gtk: Add more explicit version requirements
* :ghpull:`30835`: Improve error messages for mismatched s arg to scatter().
* :ghpull:`30750`: FIX: when creating a canvas from a Figure use original dpi
* :ghpull:`30822`: DOC: Define the effect of rcParams["figure.raise_window"] = False
* :ghpull:`30052`: Setting imshow(animated=True) still show does not show an image
* :ghpull:`30820`: DOC: Add parameters documentation for FFMpegFileWriter
* :ghpull:`30816`: Fix typos in API interfaces documentation
* :ghpull:`30814`: DOC: Discouraged duplicate colormaps
* :ghpull:`30813`: Add legend.linewidth to rcParam type hint
* :ghpull:`30705`: Add testing for rcParams Literal type hints
* :ghpull:`30812`: DOC: remove duplicate whatsnew heading
* :ghpull:`30810`: Fix rstcheck failures
* :ghpull:`30334`: Add support for loading all fonts from collections
* :ghpull:`30760`: Fix axis3d to include offset text in tight bounding box calculation
* :ghpull:`30780`: Add legend.linewidth parameter to control legend box edge linewidth
* :ghpull:`30799`: DOC: don't index or unpack the return value of pie
* :ghpull:`30766`: Fix colorbar alignment with suptitle in compressed layout mode
* :ghpull:`30756`: Add legend support for PatchCollection
* :ghpull:`30782`: DOC: Reintroduce glossary
* :ghpull:`29494`: github: added explicit do not merge label to label check
* :ghpull:`30784`: correct statement about available methods in ``Quiver`` docstring
* :ghpull:`30733`: ENH: introduce PieContainer and pie_label method
* :ghpull:`30783`: DOC: Add example usage to make_keyword_only()
* :ghpull:`30776`: MNT: Declare table() to be not further developed
* :ghpull:`30774`: DOC: Fix documentation error of hexbin
* :ghpull:`30607`: Implement libraqm for vector outputs
* :ghpull:`30753`: Update mpl-sphinx-theme in environment.yml
* :ghpull:`30699`: [DOC]  dev landing page admonition about AI usage/link to policy
* :ghpull:`30761`: DOC: Clarify restrictions on GenAI usage
* :ghpull:`30724`: Bump github/codeql-action from 4.31.0 to 4.31.2 in the actions group
* :ghpull:`30665`: Grammar corrections in User guide FAQ
* :ghpull:`30741`: Add :code-caption: option to plot directive
* :ghpull:`30736`: DOC: Correct grammatical issues especially on a/an usage
* :ghpull:`30627`: Remove forced fallback from FT2Font::load_char
* :ghpull:`30715`: Fix spacing in r"$\max f$".
* :ghpull:`30723`: Add file extension to whatsnew entry
* :ghpull:`30690`: Bump the actions group with 3 updates
* :ghpull:`30560`: Consistent zoom boxes
* :ghpull:`30565`: fix: Qt5Agg support darkmode icon by using svg
* :ghpull:`29989`: fix: Fix unstable tkagg small plot size.
* :ghpull:`30708`: doc: make external scipy link explicit
* :ghpull:`30511`: Update Colorizer/ColorizingArtist to work with MultiNorm
* :ghpull:`30696`: FIX: Account for horizontal/vertical lines in tightbox
* :ghpull:`30316`: Create RCKeyType
* :ghpull:`30686`: DOC: Remove notebook instructions from image tutorial
* :ghpull:`30684`: Update README links to static images
* :ghpull:`30640`: Bump the actions group across 1 directory with 6 updates
* :ghpull:`30677`: Merge branch 'main' into text-overhaul
* :ghpull:`30668`: cibw: Switch macos 13 to 15 Intel
* :ghpull:`30667`: DOC: Correct typos: lets -> let's [ci docs]
* :ghpull:`28831`: Improve the cache when getting font metrics
* :ghpull:`30655`: simplify ContourSet.draw
* :ghpull:`30652`: Stale action: sort issues by last updated
* :ghpull:`30636`: FIX: Keep legacy alpha behavior for violinplot without facecolor
* :ghpull:`30646`: merge up v3.10.7
* :ghpull:`30639`: DOC: Add note about linear colorbar scale option for TwoSlopeNorm
* :ghpull:`30629`: Fix test_mult_norm_call_types on 32-bit systems
* :ghpull:`30634`: Don't force axes limits in hist2d.
* :ghpull:`29221`: Multivariate plotting in imshow, pcolor and pcolormesh
* :ghpull:`30630`: Update first-interaction from v3.0.0 to v3.1.0
* :ghpull:`29695`: Add font feature API to Text
* :ghpull:`30608`: Prepare ``CharacterTracker`` for advanced font features
* :ghpull:`30531`: MNT: Pending-deprecate setting colormap extremes in-place
* :ghpull:`30543`: ENH: support x/y-axis zoom
* :ghpull:`30590`: MNT: Define Protocol for Animation.event_source
* :ghpull:`30619`: Include step info in str(scroll_event).
* :ghpull:`30620`: Add --debug flag to python -mmatplotlib.dviread CLI.
* :ghpull:`30499`: Improve cursor icons with RectangleSelector
* :ghpull:`30610`: Bump mpl-sphinx-theme version
* :ghpull:`30615`: Use auto to remove long typedefs in dlsym/GetProcAddress calls.
* :ghpull:`30616`: DOC: add what's new info for violin_stats
* :ghpull:`30606`: DOC: Fix raw string in mathtext unicode example
* :ghpull:`30603`: MNT: Fix some broken deprecations
* :ghpull:`30512`: pdf: Improve text with characters outside embedded font limits
* :ghpull:`29936`: Fix auto-sized glyphs with BaKoMa fonts
* :ghpull:`30573`: Add os.PathLike support to FT2Font constructor, and FontManager
* :ghpull:`30595`: ft2font: Split layouting from set_text
* :ghpull:`30596`: Cleanup donuts example.
* :ghpull:`29794`: Add language parameter to Text objects
* :ghpull:`30583`: MNT: Streamline deferred initialization of Colormap
* :ghpull:`30582`: MNT: Do not use colormap setters in tests
* :ghpull:`30567`: pdf: Merge loops for single byte text chunk output
* :ghpull:`30579`: Merge main back into text-overhaul branch to fix CI
* :ghpull:`30586`: ci: Bump Ubuntu ARM builder to 24.04
* :ghpull:`30581`: TST: Force Agg backend in test_openin_any_paranoid
* :ghpull:`30569`: Copy-edit the "fonts in pdf and postscript" table.
* :ghpull:`30208`: Make path extension a bit safer
* :ghpull:`30577`: MNT: Move all Colormap extremes setter logic into a single _set_extremes()
* :ghpull:`30562`: DOC: improve description of boilerplate.py
* :ghpull:`30566`: pdf/ps: Track full character map in CharacterTracker
* :ghpull:`30335`: Use glyph indices for font tracking in vector formats
* :ghpull:`30561`: Bump github/codeql-action from 3.30.1 to 3.30.3 in the actions group
* :ghpull:`29855`: ENH: Allow to register standalone figures with pyplot
* :ghpull:`29742`: DOC: Explain how to start the mainloop after show(block=False)
* :ghpull:`29502`: CI: remove xfail on OSX + tk due to issues in image
* :ghpull:`30514`: Prepare for MetaFont/PK font support.
* :ghpull:`30536`: DOC: Cleanup/restructure PR guidelines
* :ghpull:`30405`: ENH: Scroll to zoom
* :ghpull:`30530`: Bump the actions group across 1 directory with 10 updates
* :ghpull:`30532`: MNT: Change default name of ListedColormaps
* :ghpull:`30535`: Fix: pytest warning - GioUnix was imported without specifying version
* :ghpull:`30520`: pdf: Simplify Type 3 font character encoding
* :ghpull:`30387`: MNT: Refactor default violin KDE estimator
* :ghpull:`30462`: FIX: Mark shared Axes as stale when propagating adjustable
* :ghpull:`30507`: DOC: Clarify draft PR and move from ways to contribute to PR guidelines
* :ghpull:`30465`: removed test_image_cursor_formatting()
* :ghpull:`29939`: Parse {lua,xe}tex-generated dvi in dviread.
* :ghpull:`30510`: Update syntax for PR welcome workflow
* :ghpull:`30000`: Implement text shaping with libraqm
* :ghpull:`30408`: MNT/DOC: Deprecate anchor in Axes3D.set_aspect
* :ghpull:`30491`: merge up v3.10.6
* :ghpull:`30475`: Fix spelling error in ``contains_branch_separately`` method name
* :ghpull:`30505`: Add Linux Foundation Health Score badge to README
* :ghpull:`30423`: Fix Line3DCollection with autolim=True for lines of different lengths
* :ghpull:`30479`: Clarify inset_locator.inset_axes demo.
* :ghpull:`30467`: Let ticklabels respect set_in_layout(False).
* :ghpull:`30478`: MNT: correct _replacer docstring
* :ghpull:`30471`: DOC: Fix text formatting of imshow_extent example
* :ghpull:`30469`: Deprecate redundant axes parameter to RadialLocator.
* :ghpull:`30384`: Add datetime test for ax.violin
* :ghpull:`30470`: No need to sanitize extrema in Colorizer.set_clim
* :ghpull:`30468`: Let triage_tests support test modules with only figure_equals tests.
* :ghpull:`30433`: Use standard property alias machinery in contour().
* :ghpull:`30459`: DOC: simplify hat graph example
* :ghpull:`30456`: DOC: Correct a typo: confuzzlment -> confuzzlement
* :ghpull:`30455`: DOC: Fix typo in axes docstring
* :ghpull:`30454`: Added handling for undetermined home directory
* :ghpull:`30453`: DOC: Fix missing references on text-overhaul branch
* :ghpull:`30401`: merge up v3.10.5
* :ghpull:`30452`: DOC: Move capture_scroll What's new note to new directory
* :ghpull:`30403`: Add scroll capture functionality to WebAgg backend
* :ghpull:`29876`: MultiNorm class
* :ghpull:`30446`: Added hardcoded colormap attributes for type checker support
* :ghpull:`30441`: Bump github/codeql-action from 3.29.8 to 3.29.10 in the actions group
* :ghpull:`30328`: Fix legend ``labelcolor=‘linecolor’`` to handle various corner cases, e.g. step histograms and transparent markers
* :ghpull:`30440`: Document relative font sizes
* :ghpull:`30402`: Update release guide
* :ghpull:`30031`: merge up 3.10.3
* :ghpull:`30425`: Remove outdated reference to matplotlibbaselinemarker in tex sources.
* :ghpull:`29358`: MNT: Registered 3rd party scales do not need an axis parameter anymore
* :ghpull:`30422`: DOC: remove some usages of None as explicit defaults
* :ghpull:`30304`: Move release related docs to new sub-folder
* :ghpull:`30416`: Bump the actions group across 1 directory with 7 updates
* :ghpull:`30404`: DOC: Scale axis parameter
* :ghpull:`30324`: Make PyFT2Font a subclass of FT2Font
* :ghpull:`30362`: {,Range}Slider: accept callable valfmt arguments
* :ghpull:`30226`: ENH: Add properties bottoms, tops, and position_centers to BarContainer
* :ghpull:`30398`: TST: Remove qt_core fixture
* :ghpull:`30396`: Fix the link to latest stable documentation
* :ghpull:`30382`: MNT: Remove explicit use of default value add_collection(..., autolim=True)
* :ghpull:`30383`: DOC: Simplify Line, Poly and RegularPoly example
* :ghpull:`29958`: ENH: ax.add_collection(..., autolim=True) updates view limits
* :ghpull:`30374`: TST: Make determinism test plots look less pathological
* :ghpull:`29716`: ENH: Add align parameter to broken_barh()
* :ghpull:`30284`: Fixed the overdeletion of source images for failing tests
* :ghpull:`30348`: Keep default minor log ticks if there's 1 major & 1 minor tick.
* :ghpull:`30273`: Fix mlab fallback for 32-bit systems
* :ghpull:`30143`: TYP: Make glyph indices distinct from character codes
* :ghpull:`29465`: ENH: Type the possible str legend locs as Literals
* :ghpull:`30375`: Fix highlighting of install docs.
* :ghpull:`30376`: Shorten setup of axes in simple_axis_pad demo.
* :ghpull:`30367`: Support passing xticks/yticks when constructing secondary_axis.
* :ghpull:`30368`: Switch get_grid_info to take a single Bbox as parameter.
* :ghpull:`29993`: Trigger events via standard callbacks in widget testing.
* :ghpull:`30363`: Register 'avif' format when available in Pillow
* :ghpull:`29890`: Show subprocess stdout and stderr on pytest failure
* :ghpull:`30373`: Mnt/test qol improvements
* :ghpull:`30359`: ENH: Allow tuple for borderpad in AnchoredOffsetbox
* :ghpull:`30366`: Cross-ref the two-scales and secondary-axes examples.
* :ghpull:`30349`: Axes can't set navigate_mode.
* :ghpull:`30347`: Small cleanups.
* :ghpull:`30322`: Deprecate setting text kerning factor to any non-None value
* :ghpull:`30332`: CI: Harden GHA configuration
* :ghpull:`30346`: MNT: Fix isort line length setting
* :ghpull:`30314`: [MNT] Typing: correct typing overloads for ````Figure.subfigures````
* :ghpull:`30343`: Fix broken/deprecated documentation links in MEPs and testing guides
* :ghpull:`30330`: [fix] Spine.set_bounds() does not take parameter **None** as expected
* :ghpull:`30339`: MNT: Prefer capitalized logging levels
* :ghpull:`30340`: Bump the actions group with 2 updates
* :ghpull:`30302`: [MNT] Typing: Use Literal for set_loglevel
* :ghpull:`30001`: Include close matches in error message when key not found
* :ghpull:`30333`: FIX: cast Patch linewidth to float for dash scaling
* :ghpull:`30329`: Deprecate font_manager.is_opentype_cff_font
* :ghpull:`25573`: FIX: be very paranoid about checking what the current canvas is
* :ghpull:`30319`: Don't set a default size for FT2Font
* :ghpull:`29816`: Update FreeType to 2.13.3
* :ghpull:`30317`: fix broken configobj link
* :ghpull:`30261`: [TYP] Add more literals to MarkerType
* :ghpull:`30312`: Replace deprecated imports
* :ghpull:`30315`: Fix link to pango
* :ghpull:`30272`: Log a warning if selected font weight differs from requested
* :ghpull:`30311`: Bump the actions group with 2 updates
* :ghpull:`30309`: Improve custom sphinx link redirect extension
* :ghpull:`30174`: FIX: Ensure Locators on RadialAxis are always correctly wrapped
* :ghpull:`30281`: Fix several minor typos
* :ghpull:`30275`: Create events type and update plt.connect and mpl_connect
* :ghpull:`30279`: fix(config): Correct invalid value for svg.fonttype in matplotlibrc
* :ghpull:`30134`: Add typing to AFM parser
* :ghpull:`30274`: ci: Fix image preload with multiple conflicts
* :ghpull:`30231`: ci: Preload existing test images from text-overhaul-figures branch
* :ghpull:`29115`: Use old stride_windows implementation on 32-bit builds
* :ghpull:`30235`: Don't expose private styles in style.available
* :ghpull:`30266`: DOC: fix artist see also sections
* :ghpull:`30258`: Clean up mypy & ruff config
* :ghpull:`30262`: Tweak docstrings of get_window_extent/get_tightbbox.
* :ghpull:`30239`: Upgrade to Visual Studio 2022 in appveyor.yml
* :ghpull:`30245`: Adjust logic in RcParams to allow for inheritance
* :ghpull:`30232`: Bump github/codeql-action from 3.29.0 to 3.29.2 in the actions group
* :ghpull:`30196`: agg: Replace facepair_t with std::optional
* :ghpull:`30200`: Add explicit signatures for pyplot.{polar,savefig,set_loglevel}
* :ghpull:`30178`: Abstract base class for Normalize
* :ghpull:`30220`: BUG: Include python-including headers first in src/ft2font.{cpp,h}
* :ghpull:`30199`: Add explicit getter / setter overloads for pyplot.{xlim,ylim}
* :ghpull:`30202`: Add explicit overloads for pyplot.{show,subplot}
* :ghpull:`29988`: Refactoring: Removing axis parameter from scales
* :ghpull:`30082`: Simplify dviFontInfo layout in backend pdf.
* :ghpull:`30163`: Prepare to turn matplotlib.style into a plain module.
* :ghpull:`30206`: Use collections.deque to store animation cache data.
* :ghpull:`29481`: Support individual styling of major and minor grid through rcParams
* :ghpull:`28764`: Fix argument types in examples and tests
* :ghpull:`30197`: DOC: Remove last userdemo example
* :ghpull:`30191`: Simplify RendererAgg::draw_markers buffers
* :ghpull:`30188`: Fixed incomplete deletion of all images that have passed tests before upload
* :ghpull:`30168`: Remove fallback code for glyph indices
* :ghpull:`29102`: TST: Calculate RMS and diff image in C++
* :ghpull:`30145`: Remove ttconv backwards-compatibility code
* :ghpull:`30181`: Bump the actions group with 3 updates
* :ghpull:`28187`: Add a filename-prefix option to the Sphinx plot directive
* :ghpull:`30154`: Bump github/codeql-action from 3.28.18 to 3.28.19 in the actions group
* :ghpull:`30054`: Fixed an off-by-half-pixel bug in image resampling when using a nonaffine transform (e.g., a log axis)
* :ghpull:`30150`: Update font-related documentation
* :ghpull:`29199`: Fix center of rotation with rotation_mode='anchor'
* :ghpull:`30153`: Throw exception when alpha is out of bounds
* :ghpull:`30151`: Fix typo in backend_ps.py comment: change 'and them scale them' to 'and then scale them'
* :ghpull:`30107`: Add example to histogram colorbar on galleries
* :ghpull:`20716`: Type-1 font subsetting
* :ghpull:`30067`: Remove deprecations: is_bbox and more
* :ghpull:`28560`: ENH: Add grouped_bar() method
* :ghpull:`30137`: BLD: Remove FreeType from Agg backend extension
* :ghpull:`29392`: Fill hatch in PDF backend
* :ghpull:`30130`: Make NavigationToolbar.configure_subplots return value consistent
* :ghpull:`30132`: DOC: Clarify that types in docstrings do not use formal type annotation syntax
* :ghpull:`30131`: DOC: Document the properties of Normalize
* :ghpull:`30112`: Update to docs with regards to colorbar and colorizer
* :ghpull:`30004`: Remove apply_theta_transforms argument
* :ghpull:`30070`: Deprecate point_at_t and document that a BezierSegment can be called
* :ghpull:`30121`: Clean up AFM code
* :ghpull:`30123`: Fix FT_CHECK compat with macOS 10.15
* :ghpull:`30088`: Parse FontBBox in type1font.
* :ghpull:`30099`: Fix tight-bbox computation of HostAxes.
* :ghpull:`30102`: Simplify/improve error reporting from ft2font.
* :ghpull:`30113`: Bump scientific-python/circleci-artifacts-redirector-action from 1.0.0 to 1.1.0 in the actions group
* :ghpull:`30100`: Use fix-cm instead of type1cm.
* :ghpull:`30109`: DOC: expand petroff10 example to include 6- and 8- styles
* :ghpull:`30044`: Replace FT2Image by plain numpy arrays.
* :ghpull:`30097`: remove point troubling regex
* :ghpull:`30090`: Simplify some Sphinx tests
* :ghpull:`30061`: Move test data into a single subdirectory
* :ghpull:`30085`: DOC: add API docs content guidelines to api docs instructions
* :ghpull:`30084`: DOCS: add plot types content guidance to docs
* :ghpull:`30087`: DOC: Add petroff6 and petroff8 to 'Named color sequences' example
* :ghpull:`30080`: Bump the actions group with 3 updates
* :ghpull:`30065`: ENH: Add Petroff 6 and 8 color cycle style sheets
* :ghpull:`30077`: Fix deprecated attribute name in backend_pdf.
* :ghpull:`30069`: Close star polygons
* :ghpull:`30062`: Add 3D scatter test for cmap update
* :ghpull:`30066`: Remove get_bbox_header
* :ghpull:`30045`: CI: try running the precommit hooks on GHA
* :ghpull:`29910`: DOC: add warnings about get_window_extent and BboxImage
* :ghpull:`30032`: Add Matplotlib Journey online course to external resources
* :ghpull:`30055`: Renamed an RST file to remove a leading space in its filename
* :ghpull:`30049`: DOC: consolidate version switcher guidance
* :ghpull:`30050`: DOC: Additional tip to exclude undesired matches in GitHub code search
* :ghpull:`30005`: Remove cm.get_cmap
* :ghpull:`30048`: DOC: version switcher update on release
* :ghpull:`30047`: Update version switcher for 3.10.3
* :ghpull:`30036`: Remove cutout for missing font file in PdfFile._embedTeXFont.
* :ghpull:`29847`: ci: restrict 'pygobject-ver' for Ubuntu 22.04 jobs
* :ghpull:`30030`: Add "sans" alias to rc() to allow users to set font.sans-serif
* :ghpull:`30040`: Improve usetex and pgf troubleshooting docs.
* :ghpull:`30037`: Update top message matplotlibrc file
* :ghpull:`30035`: Remove meson-python pinning
* :ghpull:`30006`: Enable linting of .pyi files
* :ghpull:`30020`: Micro-optimize _to_rgba_no_colorcycle.
* :ghpull:`30027`: Make PdfFile font-related attributes private.
* :ghpull:`29829`: Rework mapping of dvi glyph indices to freetype indices.
* :ghpull:`30023`: Remove unused ``_api`` import
* :ghpull:`30014`: Remove deprecated get_tick_iterator()
* :ghpull:`30015`: Expire deprecation of nth_coord arguments
* :ghpull:`30019`: FIX #30007: Raise ValueError when all wedge sizes are zero in ax.pie
* :ghpull:`30016`: Bump github/codeql-action from 3.28.16 to 3.28.17 in the actions group
* :ghpull:`30003`: DOC: missing word + add latex dep section
* :ghpull:`29341`: Type annotation add_subplot for projection="3d"
* :ghpull:`29764`: added latex requirements from fedora spec
* :ghpull:`29918`: DOC: Add descriptions to matplotlib.typing
* :ghpull:`27576`: Fix specifying number of levels with log contour
* :ghpull:`29879`: Adding elinestyle property to errorbar
* :ghpull:`29984`: FIX: Typing of FuncAnimation
* :ghpull:`29973`: Use inline lambdas to define most FT2Font properties.
* :ghpull:`29982`: Bump the actions group with 5 updates
* :ghpull:`29972`: Improve repr of mathtext internal structures; minor cleanup.
* :ghpull:`29356`: Add a last resort font for missing glyphs
* :ghpull:`29873`: Handled non finite values in ax.pie - issue #29860
* :ghpull:`29916`: Bump the actions group with 2 updates
* :ghpull:`27183`: Fix behaviour of Figure.clear() for SubplotParams
* :ghpull:`29954`: Simplify ``colored_line()`` implementation in Multicolored lines example
* :ghpull:`29956`: MNT: make signature of GridSpec.update explicit
* :ghpull:`29203`: Fixed imsave() saving incorrect color map
* :ghpull:`29946`: Changed "Autoscaling axes" to "Autoscaling axes on user guide page for issue & closes #29906
* :ghpull:`29948`: Check Axes/Figure import paths in boilerplate.py
* :ghpull:`29904`: API: bump minimum supported version of Python and numpy
* :ghpull:`29945`: Doc fixed aspect colorbar
* :ghpull:`29944`: DEV: have ruff check blank-line counts
* :ghpull:`29923`: Fix signature of disabled draw methods
* :ghpull:`29614`: add detail to doc string in Line3DCollection
* :ghpull:`29843`: Fix loading of Type1 "native" charmap.
* :ghpull:`29911`: Bump pre-commit versions
* :ghpull:`29892`: FIX: make_image should not modify original array
* :ghpull:`29905`: Remove hatchcolors parameter from draw_quad_mesh
* :ghpull:`29898`: backend_bases.pyi: ``@overload`` ``FigureCanvasBase.mpl_connect()`` for different event types
* :ghpull:`29745`: Use PEP8 style method and function names from pyparsing
* :ghpull:`29762`: Use ruff instead of flake8 to check PEP8
* :ghpull:`29885`: Bump github/codeql-action from 3.28.13 to 3.28.14 in the actions group
* :ghpull:`29592`: DOC: Remove simple_legend examples from User Demo
* :ghpull:`29875`: DOC: Improve description of background/bbox handling for Text
* :ghpull:`29612`: ENH: Support units when specifying the figsize
* :ghpull:`29833`: TST: remove (most) text from constrained layout tests
* :ghpull:`29870`: doc: a grammatical error in pyplot comment
* :ghpull:`29831`: Inline _calc_extents_from_path.
* :ghpull:`29851`: Do not extraneously clip 3D plots
* :ghpull:`29846`: ci: cleanup: remove stale/outdated version range restrictions
* :ghpull:`29841`: Bump the actions group with 2 updates
* :ghpull:`29850`: MNT: Use Gcf.destroy(manager) instead of Gcf.destroy(manager.num)
* :ghpull:`29765`: ci: Introduce ubuntu-24.04 to restore GTK test coverage with recent PyGObject versions
* :ghpull:`29838`: Switch Tfm metrics to TrueType-compatible API.
* :ghpull:`29783`: Fix log scaling for pcolor and pcolormesh
* :ghpull:`29832`: MNT: expire legend-related deprecations
* :ghpull:`29044`: Add hatchcolor parameter for Collections
* :ghpull:`29828`: Improve output of dvi debug parsing.
* :ghpull:`29798`: Ensure polar plot radial lower limit remains at 0 after set_rticks + plot
* :ghpull:`29830`: Fix git fetch on development workflow
* :ghpull:`29776`: Filter images in premultiplied alpha mode.
* :ghpull:`29821`: Tweak minimal checks for GUI binding installs.
* :ghpull:`29808`: ENH: set default color cycle to named color sequence
* :ghpull:`29817`: Prepare for {xe,lua}tex support in usetex.
* :ghpull:`27972`: Fix ngrids support in axes_grid.Grid().
* :ghpull:`29804`: replace quansight-labs/setup-python with actions/setup-python
* :ghpull:`29800`: Bump the actions group with 6 updates
* :ghpull:`29083`: DOC: Update page to note installation for ninja library
* :ghpull:`29698`: Improve tick subsampling in LogLocator.
* :ghpull:`29701`: Bump the actions group across 1 directory with 7 updates
* :ghpull:`28352`: Add compilers to conda environment
* :ghpull:`29696`: ENH: Add support for per-label padding in bar_label
* :ghpull:`29582`: Add ``rasterized`` option to ``contourf``
* :ghpull:`29759`: DOC: expand use of fun tag
* :ghpull:`29758`: DOC: consolidate tags
* :ghpull:`29756`: Consolidate color tags
* :ghpull:`29747`: Revert "NEP 29 > SPEC 0 in dependency policy"
* :ghpull:`29744`: NEP 29 > SPEC 0 in dependency policy
* :ghpull:`29700`: merge up v3.10.1
* :ghpull:`26774`: Connect the Animation event source callback in the constructor.
* :ghpull:`29729`: DOC: Improve What's new entry description
* :ghpull:`29718`: Update version switcher for 3.10.1
* :ghpull:`29602`: MNT: Reduce the use of get_xticklabels() in examples
* :ghpull:`29705`: DOC: improve dev install docs
* :ghpull:`29644`: [Doc] Added images of hatches to hatch API page
* :ghpull:`29697`: MNT: remove ``plot_date``
* :ghpull:`29690`: Add test cases for patch.force_edgecolor behavior with facecolor="none"
* :ghpull:`29558`: Consolidate align_labels_demo and align_ylabels gallery examples
* :ghpull:`29660`: fix: broken link
* :ghpull:`29639`: Bump the actions group across 1 directory with 7 updates
* :ghpull:`29620`: DOC: Add tip how to use GitHub code search to estimate the impact of a deprecation
* :ghpull:`29613`: doc: add link to analytics page
* :ghpull:`29593`: Fix tick_params() label rotation mode
* :ghpull:`29589`: DOC: Minor example cleanup
* :ghpull:`29580`: DOC: More cleanup of missing-references.json
* :ghpull:`29581`: Use functools.cache instead of lru_cache to establish singletons.
* :ghpull:`29566`: DOC: Remove invalid link in Communication Guide
* :ghpull:`29565`: Remove rcParams deprecation machinery
* :ghpull:`29561`: DOC: Document _CollectionWithSizes
* :ghpull:`29569`: Ignore ImageMagick deprecation of "convert" command.
* :ghpull:`29574`: 3D depthshade what's new plot
* :ghpull:`29052`: FIX: Checks for (value, color) tuples in LinearSegmentedColormap.from_list
* :ghpull:`29556`: Spacing for description of linecolor
* :ghpull:`28784`: Improve fallback font export tests
* :ghpull:`28968`: Implement xtick and ytick rotation modes
* :ghpull:`29450`: Remove some unused resample code
* :ghpull:`29503`: Improve error message for shape mismatches in barh function
* :ghpull:`29553`: DOC: update active social media list
* :ghpull:`27304`: Allow user to specify colors in violin plots with constructor method
* :ghpull:`29287`: Fix depth shading on 3D scatterplots
* :ghpull:`29398`: Speed up Collection.set_paths
* :ghpull:`29525`: Add new method Colormap.with_alpha()
* :ghpull:`29537`: Fix: Ensure ScalarFormatter.set_useOffset properly distinguishes betw…
* :ghpull:`29533`: Minor cleanups.
* :ghpull:`29397`: 3D plotting performance improvements
* :ghpull:`29529`: MNT: Deprecate other capitalization than "None" in matplotlibrc
* :ghpull:`29526`: DOC: better separation of codespace instructions
* :ghpull:`29486`: FIX: Make stem() baseline follow the curvature in polar plots
* :ghpull:`29460`: ENH: Add bad, under, over kwargs to Colormap
* :ghpull:`29435`: Fix ``plot_wireframe`` with nonequal ``rstride``, ``cstride``, plus additional speedups
* :ghpull:`29491`: Bump the actions group across 1 directory with 2 updates
* :ghpull:`29375`: Doc: document pending deprecation procedure
* :ghpull:`29497`: ci: Fix cache key for Matplotlib data
* :ghpull:`29473`: CI: add py312 and py313 on windows on azure to test matrix
* :ghpull:`29477`: ci: Add an ARM Linux test workflow
* :ghpull:`29372`: DOC / BUG: Fix savefig to GIF format with .gif suffix
* :ghpull:`29028`: Update colormap usage documentation to prioritize string colormap names
* :ghpull:`29461`: DOC: Use color specification reference in matplotlib.colors docs
* :ghpull:`29438`: ft2font: Avoid undefined enum values
* :ghpull:`29463`: Fix dead links in dev workflow docs
* :ghpull:`29464`: DOC: Add missing examples for legend outside positions
* :ghpull:`29433`: Remove erroneous statement in multipage PDF example
* :ghpull:`29441`: DOC: Rename Twitter to X
* :ghpull:`29399`: plot_wireframe plotting speedup
* :ghpull:`29325`: Propagate Axes class and kwargs for twinx and twiny
* :ghpull:`29424`: MNT: Turn Axes._axis_map into a static dict instead of a property
* :ghpull:`29427`: BUG: Fix regression with set_hatchcolor
* :ghpull:`29419`: Merge v3.10.x into main
* :ghpull:`29413`: [pre-commit.ci] pre-commit autoupdate
* :ghpull:`29415`: Bump the actions group across 1 directory with 5 updates
* :ghpull:`29338`: Use set_window_title rather than set_label to set title of webagg figure
* :ghpull:`29388`: FIX: get_tick_position() should disregard major/minor ticks that are not drawn
* :ghpull:`27327`: Update for checking whether colors have an alpha channel
* :ghpull:`29405`: DOC: Clearer wording for the installation of external dependencies
* :ghpull:`29402`: Expand set_ticklabels warning
* :ghpull:`29400`: Fix/Suppress more missing references
* :ghpull:`29394`: Tick rendering speedups
* :ghpull:`29386`: MNT: Remove ``*args`` for ``OffsetBox.__init__()``
* :ghpull:`28104`: Separates edgecolor from hatchcolor
* :ghpull:`29377`: DOC: change wording on new contributor path
* :ghpull:`29376`: API: bump the minimum version of pillow
* :ghpull:`29333`: ENH: Streamplot control for integration max step and error
* :ghpull:`29342`: MNT: Warn on using pixel marker for scatter()
* :ghpull:`29344`: MNT: Coerce LineStyleType strings to Literal
* :ghpull:`29354`: Use _val_or_rc in more places
* :ghpull:`29360`: DOC: update switcher for 3.10
* :ghpull:`29174`: ``indicate_inset`` transform support
* :ghpull:`27551`: Move axisartist towards untransposed transforms (operating on (N, 2) arrays instead of (2, N) arrays).
* :ghpull:`24714`: Improve handling of degenerate jacobians in non-rectilinear grids.
* :ghpull:`29343`: MNT: Discourage alternate strings for 'none' linestyle
* :ghpull:`29054`: Label log minor ticks if only one log major tick is drawn.
* :ghpull:`29346`: DOC: fix typos
* :ghpull:`29340`: FIX: pass renderer through adjust_bbox
* :ghpull:`29345`: MNT: Remove duplicate assignment
* :ghpull:`29329`: CI: allow pandas install to fail on nightly test run
* :ghpull:`29322`: DOC: Add [*Discouraged*] prefix to summary lines
* :ghpull:`25870`: Adds error handling around install_repl_displayhook
* :ghpull:`29303`: DOC: Enhance documentation on discouraged API
* :ghpull:`29280`: Apply some modernization to C++ extensions
* :ghpull:`23085`: Update art3d.py to address strange behavior of depthshading on 3D scatterplots with close points
* :ghpull:`29215`: added venv to gitignore
* :ghpull:`29257`: fix typo
* :ghpull:`28775`: DOC: manually placing images example
* :ghpull:`29222`: TST: Simplify parts of animation tests
* :ghpull:`29220`: DOC: Set stable version to 3.9.3
* :ghpull:`29214`: Fix typo in _LazyTickList class comment (lis -> list)
* :ghpull:`29171`: ci: Remove Linux & macOS from Azure
* :ghpull:`29187`: DOC: verify your changes
* :ghpull:`29184`: Minor tweaks to image docs.
* :ghpull:`29172`: Minor cleanups to docstrings, comments, and error messages.
* :ghpull:`29155`: Delay warning for deprecated parameter 'vert' of box and violin
* :ghpull:`27617`: Add new num_arrows option to streamplot
* :ghpull:`29135`: Deprecate ListedColormap(..., N=...) parameter
* :ghpull:`29147`: Simplify synthetic event generation in interactive pan/zoom tests.
* :ghpull:`29150`: TST: Run macosx backends in a subprocess
* :ghpull:`29066`: Check pressed mouse buttons in pan/zoom drag handlers.
* :ghpull:`29087`: DOC: escape broken cross links
* :ghpull:`29127`: MNT: Refactor matplotlib.colors.from_levels_and_colors()
* :ghpull:`29125`: Make ListedColormap.monochrome a property
* :ghpull:`29074`: Add "standard" Axes wrapper getters/setters for Axis invertedness.
* :ghpull:`29078`: Document how to discourage API
* :ghpull:`29079`: DOC: Replaced colormap for colorblindness
* :ghpull:`29077`: DOC: Replaced green with blue for colorblindness

Issues (246):

* :ghissue:`14235`: Add \underline to mathtext?
* :ghissue:`31462`: [Bug]: Errorbar plot on log-scaled Axes sets incorrect automatic lower limits
* :ghissue:`30859`: [Bug]: ax.relim() ignores scatter artist
* :ghissue:`31523`: [Bug]: twinx() and twiny() crash with cryptic errors on 3D axes
* :ghissue:`26901`: [ENH]: Remove ``canvas.draw`` from ``widgets.Cursor.onmove``
* :ghissue:`30831`: [Bug]: AttributeError: 'TimedAnimation' object has no attribute '_framedata'
* :ghissue:`31513`: [Bug]: Flaky test_contour.py::test_labels on minver CI
* :ghissue:`24716`: [TST]: Add classic style to all old image tests.
* :ghissue:`28488`: [ENH]: Provide a way to avoid subcommands on import.
* :ghissue:`30413`: [MNT]: c++11 narrowing error when building for 32 bit targets
* :ghissue:`31122`: [ENH]: Give control whether twinx() or twiny() overlays the main axis
* :ghissue:`4822`: Light font variants cannot be accessed by common name
* :ghissue:`21409`: [Bug]: twinx and twiny ignores previous set_position
* :ghissue:`31404`: [Bug]: Crash when removing contour set after removing contour labels
* :ghissue:`30365`: [Bug]: Type hints for xy and xycoords in annotate are too strict
* :ghissue:`13044`: Center of rotation for text with rotation_mode='anchor'
* :ghissue:`29253`: [Bug]: Numbers in words not italic
* :ghissue:`31220`: Should we use font metrics for line height instead of "lp"?
* :ghissue:`22172`: [Bug]: \genfrac has bad spacing with (high) custom ruler
* :ghissue:`18389`: Vertical positioning in mathtext fraction rendering could be improved
* :ghissue:`18086`: sub/superscripts should be moved further from the baseline following large delimiters
* :ghissue:`3135`: Please add support for ttc font files (PDF/PS output)
* :ghissue:`16566`: OTF feature support (alternate figure styles, etc.)
* :ghissue:`20842`: [MNT]: Please update freetype version
* :ghissue:`8765`: Indic Script labels not rendered correctly
* :ghissue:`2071`: matplotlib can't handle "newer" TrueType fonts
* :ghissue:`23082`: [Bug]: Font rendering bug for Devanagari text
* :ghissue:`29357`: [Bug]: Incorrect rendering of Abugida fonts on Matplotlib visualization
* :ghissue:`29806`: [Feature Request] Proper Arabic Language Support in Matplotlib Plots
* :ghissue:`5210`: Unexpected replacement of \right) with exclamation point in MathTextParser output
* :ghissue:`9681`: Determine if ``hinting_factor`` setting can be dropped
* :ghissue:`21797`: [Bug]: Math fonts (Type 3) incorrectly embedded in PDF?
* :ghissue:`31464`: [Doc]: finding the simple example
* :ghissue:`31454`: [Doc]: Amend AI policy by a concrete list of dos and don’ts
* :ghissue:`31337`: wording questions
* :ghissue:`31406`: [ENH]: [Bug]: secondary_xaxes().set_xlim/xbound should warn or raise that it is ineffective
* :ghissue:`31400`: [ENH]: Support partial figsize setting
* :ghissue:`26620`: [Doc]: Improve legend loc and bbox_to_anchor documentation
* :ghissue:`31369`: Dead link in colormap docs [Ware]
* :ghissue:`31344`: [Bug]: Adding contour labels affects the shape of filled contours
* :ghissue:`31286`: [MNT]: Scale ``val_in_range`` method
* :ghissue:`30651`: [MNT]: Add copyright information for google's "turbo" colormap?
* :ghissue:`28298`: [Bug]: set linestyle='dashed' raise error with quiver and legend
* :ghissue:`31302`: ``stairs`` with dashed linestyle and fill=True raises ValueError
* :ghissue:`27870`: [ENH]: out-of-tree Pyodide builds in CI for Matplotlib
* :ghissue:`31164`: [MNT]: Adopt Scikit Learn's autoclose bot
* :ghissue:`31320`: [DOC]: Using matplotlib.pyplot.pcolormesh with shading='flat'
* :ghissue:`31247`: [Bug]: Changing limits by setting ticks does not emit "x/ylim_changed"
* :ghissue:`18159`: Add zoom_factory to matplotlib - where to put?
* :ghissue:`31235`: [Doc]: bad rendering of matplotlib.pyplot.quiver docs
* :ghissue:`31126`: [Bug]: FigureCanvasTkAgg renders clipped/oversized when embedded in layout-managed container on Windows HiDPI
* :ghissue:`15313`: star (*) symbol in text box cuts off bottom of text when saved
* :ghissue:`31182`: [Bug]: ``ax.hist()`` fails on sequence of timedeltas due to comparison with ``np.inf``
* :ghissue:`31256`: [ENH]: Extend semilogx, etc to 3D
* :ghissue:`209`: 3D scatter plots don't work in logscale
* :ghissue:`23306`: [ENH]: allow passing a function to ``CallbackRegistry.disconnect``
* :ghissue:`28766`: [Bug]: Alignment of minus sign when using LaTeX
* :ghissue:`31093`: [ENH]: Modifier key to discretize rotations for 3D plots
* :ghissue:`31194`: [ENH]: add ``errorbar.capthick`` and ``errorbar.elinewidth`` to mplstyle
* :ghissue:`31221`: [Doc]: ticks/ticklabels_rotation example should mention rotation_mode="xtick"/"ytick"
* :ghissue:`20779`: [ENH]: move .matplotlib folder from %USERPROFILE% on Windows
* :ghissue:`31225`: [Bug]: set_edgecolor(None) cannot recover the default style after changing the edge color of wedges with hatches
* :ghissue:`26092`: [Bug]: alpha array-type not working with RGB image in imshow()
* :ghissue:`31009`: [Bug]: Large pixels may overlap when using imshow()
* :ghissue:`31127`: [Doc]: quiver 3d does not support "mid" as an alias for "middle", but quiver 2d does
* :ghissue:`30848`: [MNT]: Should we request contributors to declare usage of AI?
* :ghissue:`25914`: [Doc]: replace usages of ``.imread`` with PIL.Image.open
* :ghissue:`30934`: [ENH]: Implement gapcolor for patch edges
* :ghissue:`24499`: [Doc]: Transformation tutorial uses outdated description for polar transform
* :ghissue:`31149`: [ENH]: Improve compatibility with array-like objects implementing __array__ (e.g. MLX arrays)
* :ghissue:`31135`: [Bug]: Setting figure for polar axes breaks the polar coordinates
* :ghissue:`28793`: ``patheffects.SimpleLineShadow`` calling non-existent ``get_foreground`` method from GraphicsContextBase
* :ghissue:`30658`: [MNT]: First contributor workflow fails for first contributors
* :ghissue:`19299`: wide mathtext accents are mis-centered
* :ghissue:`31086`: [Bug]: Colorbar get_ticks() return the incorrect array
* :ghissue:`2488`: Off-axes scatter() points unnecessarily saved to PDF when coloured
* :ghissue:`29551`: [Bug]: 3D tick label position jitter when rotating the plot view
* :ghissue:`30957`: [MNT]: Clarify the difference between Artist.set and Artist.update
* :ghissue:`30996`: [Doc]: ``contour`` and ``contourf`` levels default not specified
* :ghissue:`31003`: [ENH]: Add types for ``fig_kw`` argument in ``subplots``
* :ghissue:`30417`: [ENH]: Support using datetimes as ``positions`` argument to violin(...)
* :ghissue:`30575`: [Bug]: Regression in widget behavior
* :ghissue:`23763`: [Bug]: Inconsistent rendering between backends when rendering Mathtext horizontal rule
* :ghissue:`23860`: [Bug]: Font weight of label cannot be overwritten from rcParams when using mathtext
* :ghissue:`29475`: [Doc]: interactive rebase instructions outdated?
* :ghissue:`29863`: [ENH]: Should we hide _preprocess_data from the stack trace?
* :ghissue:`30836`: [Bug]: Markers can be integers, but numpy integers fail
* :ghissue:`22231`: [Bug]: Axes.grid(color) ignores alpha
* :ghissue:`14143`: imshow pixel boundaries wrong when zoomed in
* :ghissue:`1441`: Misalignment imshow vs. grid lines
* :ghissue:`30882`: [Bug]: Flaky tests with "Python 3.11 on ubuntu-22.04 (Minimum Versions)"
* :ghissue:`27590`: [Bug]: Qt5 backend icons should be white when macOS in dark mode
* :ghissue:`23531`: [Doc]: Documentation of rc parameters could be improved
* :ghissue:`30559`: [ENH]: Backend versioning
* :ghissue:`30917`: [Bug]: TimerAsyncio does not work with Python 3.14
* :ghissue:`30709`: [Bug]: Mismatch in documented default behaviour of pcolormesh 'snap'
* :ghissue:`30463`: [Doc]: Two sources of a gallery figure for normal and high-DPI screen are different
* :ghissue:`28983`: [Doc]: outdated links for violin/boxplot
* :ghissue:`30857`: [Bug]: ValueError: The 'color' keyword argument must have one color per dataset
* :ghissue:`29332`: [ENH]: Typing: broaden acceptable floats
* :ghissue:`23633`: [MNT]: Deprecated / discourage less used Axes methods forwarding to Axis methods
* :ghissue:`21496`: [MNT]: MultiCursor should not take canvas as first parameter
* :ghissue:`30563`: [Bug]: 3D text does not respect rotation to make it parallel with a given zdir axis
* :ghissue:`27969`: [ENH]: Please add ``matplotlib.patches.RoundedRectangle``
* :ghissue:`29319`: [Bug]: Legend with location set to ‘best’ overlaps with the title when the titles is moved down
* :ghissue:`28513`: [Bug]: Segfault when using ``close_event`` with macosx backend and tk
* :ghissue:`30840`: [MNT]: ``LocationEvent.modifiers`` missing in type stub
* :ghissue:`30770`: [Bug]: Bug / Inconsistency: Title Format Lost After Interactive Editing
* :ghissue:`30673`: [ENH]: Add custom hatch styling to grouped_bar
* :ghissue:`30804`: [Bug]: Stackplot does not pass ``facecolor(s)`` correctly to fill_between
* :ghissue:`30537`: Permanent solution for GioUnix warning
* :ghissue:`27224`: [Bug]: pickling and unpickling hidpi a qt figure that has been already shown doubles its physical size
* :ghissue:`26380`: [Bug]: DPI keeps doubling when creating a new MatPlotLib QtWidget in qt6
* :ghissue:`20415`: figure.raise_window keyword produces inconsistent results
* :ghissue:`18985`: Why does setting imshow(animated=True) still show an image?
* :ghissue:`22831`: [Doc]: Arguments of FFMpegFileWriter not clear.
* :ghissue:`30796`: [Doc]: Information about deprecated colormaps missing from recent versions of the documentation
* :ghissue:`7059`: Decoupling hatch from edges
* :ghissue:`30744`: [Bug]: axis3d.Axis.get_tightbbox() is not including the offset_text
* :ghissue:`30767`: [ENH]: Add rcParams for the width of the legend's box edge
* :ghissue:`30472`: [Bug]: layout=compressed conflict with suptitle
* :ghissue:`23998`: Labels for PatchCollection do not show
* :ghissue:`28889`: [Doc]: Reintroduce glossary for matplotlib terms and concepts
* :ghissue:`22402`: [Doc]: Quiver docstring incorrectly claims that only ``UVC`` can be set
* :ghissue:`19338`: Allow option to display absolute values for pie chart
* :ghissue:`30664`: [MNT]: Declare table() to be not further developed
* :ghissue:`30764`: [Bug]: Hexbin with bins='log' doesn't handle zeros as described
* :ghissue:`30439`: [Doc]: Link AI policy on contributing page
* :ghissue:`30740`: [ENH]: Support caption for code block in sphinx plot directive
* :ghissue:`30695`: [Bug]: bbox_inches='tight' works differently when ax.plot() have markers
* :ghissue:`30257`: [MNT] [TYPING]: Use of Literal
* :ghissue:`20724`: ToolHandles/ToolLineHandles could set the mouse cursor when hovered over or active
* :ghissue:`20554`: Remove discussion of jupyter backends from image tutorial
* :ghissue:`28827`: [Bug]: FontProperties objects are not deleted when using fig.savefig
* :ghissue:`30644`: [Doc]: Stable docs reporting as unstable
* :ghissue:`30613`: [Bug]: violin's default alpha no longer persists
* :ghissue:`22197`: [Bug]: TwoSlopeNorm behaves like CenteredNorm
* :ghissue:`30522`: [MNT]: PR Greeting GHA not working
* :ghissue:`30574`: [Bug]: Unicode symbols encoded with ``\u....`` with mathtext raise ParseFatalException
* :ghissue:`27190`: [Doc]: clarify when and how to use boilerplate.py
* :ghissue:`26739`: Write a separate doc-string for Line3DCollection
* :ghissue:`19956`: Native support for showing OOP-created figures
* :ghissue:`28412`: [ENH]: Zoom in/out on rolling the mouse wheel
* :ghissue:`30525`: [Bug]: Pipeline fails with "GioUnix was imported without specifying a version first"
* :ghissue:`30436`: [Doc]: new contributor guidance on draft PRs
* :ghissue:`30364`: [MNT]/[DOC]: Look into Axes3D.set_aspect ``anchor`` and ``adjustable`` arguments
* :ghissue:`30474`: [Bug]: Typo in method name: contains_branch_separately
* :ghissue:`30418`: [Bug]: error using ``add_collection3d`` of ``Line3DCollection`` with ``autolims=True`` and lines containing different numbers of points
* :ghissue:`30263`: [ENH]: Allow ignoring x-extent (but not y-extent) of xticklabels when computing axes extents (e.g. for geometry manager)
* :ghissue:`30296`: [MNT]: Deprecate the axes parameter to RadialLocator
* :ghissue:`29774`: [Bug]: triage_tests.py is brittle against failures in test modules that have only check_figures_equal test
* :ghissue:`29349`: [MNT]: Remove axis parameter from scales
* :ghissue:`1963`: Singular keyword arguments in contour don't raise exceptions
* :ghissue:`30449`: [Bug]: Config directory location finder doesn't account for the home directory being undetermined.
* :ghissue:`30438`: [Bug]: missing stubs for ``plt.cm`` (a.k.a. ``matplotlib.pyplot.cm``)
* :ghissue:`30298`: [Bug]: Legend kwarg ``labelcolor='linecolor'`` not working properly when ``facecolor`` is ``'None'``
* :ghissue:`30437`: [Doc]: Clarification of relative font sizes
* :ghissue:`30400`: [Bug]: Megabyte-level memory leak when using imshow() in a loop
* :ghissue:`29957`: [ENH]: add_collection(..., autolim=True) should update view limits as well
* :ghissue:`22720`: [MNT]: Generalize widget mouse testing
* :ghissue:`28809`: [ENH]: Support avif as output format
* :ghissue:`30331`: [ENH]: inset_axes has borderpadding, but not x/y individually.
* :ghissue:`29300`: [Bug]: Background of rotated png is rendered black
* :ghissue:`30323`: [MNT]: validate linewidth
* :ghissue:`25572`: [Bug]: Artist.remove() isn't fully removing it from figure
* :ghissue:`30325`: [Bug]: fig.savefig throws error after radiobutton axes is removed
* :ghissue:`15529`: Chinese font can``t change the weight
* :ghissue:`30164`: [Bug]: Removing spines in polar plot causes distortion of the plot
* :ghissue:`27232`: BUG:  .notdef glyph has to be present in fonts in fontlist
* :ghissue:`14239`: rotated text does not align
* :ghissue:`23021`: [Bug]: Text rotation leads to characters being misplaced within their bounding boxes. Attempted solution provided.
* :ghissue:`30160`: [MNT]: pyplot type hints
* :ghissue:`13919`: Impossible to configure minor/major grid line style independently in rcParams
* :ghissue:`25800`: [MNT]: Remove the userdemo section in examples
* :ghissue:`24313`: [ENH]: API discussion for grouped bar charts
* :ghissue:`29722`: [MNT]: Upcoming version of ``pyparsing`` will start emitting ``DeprecationWarnings`` for legacy pre-PEP8 method and argument names
* :ghissue:`30026`: [Doc]: add histogram as colorbar example
* :ghissue:`127`: When text.usetex=True with pdf backend, full subset of latex fonts is embedded into pdf file
* :ghissue:`10034`: Hatching is rendered differently by agg, pdf and svg backends.
* :ghissue:`19832`: Positioning floating_axes.FloatingSubplot
* :ghissue:`29791`: [Bug]: Saving as an SVG and PDF produce different outputs with Latex characters, with wrong character sizing
* :ghissue:`28675`: [Bug]: ``multialignment='right'`` in ``ax.text()`` with ``path_effects`` breaks when using LaTeX package ``\usepackage[T1]{fontenc}``
* :ghissue:`27654`: [MNT]: Use fix-cm rather than type1cm for LaTeX
* :ghissue:`30086`: Add petroff6 and petroff8 color cycles to named color sequences example
* :ghissue:`30060`: Add the 6 color and 8 color sequence for the Petroff color cycles
* :ghissue:`28750`: Followup documentation for petroff color sequence
* :ghissue:`18931`: 3D collections do not proper handle ``edgecolor='face'``
* :ghissue:`2831`: Bug when saving to vector format (pdf, svg, eps)
* :ghissue:`30046`: [Doc]: Documentation of the stable version still prompts that it is an unstable development version
* :ghissue:`29844`: [MNT]: CI: pygobject fails to install during ubuntu-22.04 GitHub Actions jobs
* :ghissue:`30021`: [Bug]: Setting font.sans-serif is impossible by the intended way using matplotlib.rc because it contains a hyphen.
* :ghissue:`30007`: Axes.pie([0, 0]) crashes with “cannot convert float NaN to integer” when all slice sizes are zero
* :ghissue:`29334`: [Bug]: Type annotation for ``add_subplots`` has incorrect return type for ``projection="3d"``
* :ghissue:`29681`: [ENH]: Add parameter 'error_linestyle' to plt.errorbar()
* :ghissue:`29960`: [Bug]: FuncAnimation function not typed properly
* :ghissue:`29860`: ``ax.pie()`` raises ``ValueError`` when input contains ``NaN``
* :ghissue:`11059`: figure.clf() and subplots_adjust
* :ghissue:`29906`: [Doc]: Autoscaling Axes or Autoscaling Axis?
* :ghissue:`29921`: boilerplate.py seems to remove parameters
* :ghissue:`29938`: [ENH]: plt.colorbar add a colorbar which has the same height/width of original image
* :ghissue:`29891`: [Bug]: image alpha re-applied each draw?
* :ghissue:`29883`: [Bug]: Missing backcompat for backends not supporting hatchcolors in draw_quad_mesh
* :ghissue:`27588`: [ENH]: Add way to automatically fix flake8 errors
* :ghissue:`1369`: add rc param for centimeter support
* :ghissue:`29845`: [MNT]: CI: cleanup: remove stale/outdated version range restrictions
* :ghissue:`29749`: [Bug]: Unit tests: Ubuntu 22.04 lacks dependencies required for recent PyGObject versions
* :ghissue:`29615`: [Bug]: pcolormesh's default x/y range might break ``set_scale('log')``
* :ghissue:`29528`: [Bug]: set_rticks makes polar autoscale move the origin away from zero
* :ghissue:`29799`: [ENH]: set default color cycle to named color sequence
* :ghissue:`29694`: [Bug]: LogLocator sometimes draws fewer ticks than it can
* :ghissue:`29746`: [Doc]: Add uv and pixi install instructions
* :ghissue:`29647`: [ENH]: Allow list of padding values for bar_label
* :ghissue:`27669`: [Doc]: documentation of how to properly rasterize output of contourf
* :ghissue:`29757`: [Doc]: duplicate tags
* :ghissue:`29753`: [Doc]: color and colormap tags
* :ghissue:`29720`: [Bug]: Inset Axes Failing for Geographic Plot
* :ghissue:`29712`: [Doc]: Stable version of documentation has unstable banner
* :ghissue:`27196`: [Doc]: List supported hatches and link to/embed hatch reference on hatches API page
* :ghissue:`29562`: [MNT]: Remove rcParams deprecation machinery
* :ghissue:`29042`: [Bug]: colors.LinearSegmentedColormap.from_list fails when using a ("<color>", alpha) tuple
* :ghissue:`28951`: [ENH]: Better positioning of rotated tick labels
* :ghissue:`29474`: [ENH]: Show parameter names in error message for mismatched array sizes in bar()
* :ghissue:`27298`: [ENH]: Add color argument to violinplot constructor
* :ghissue:`22861`: [Bug]: 3D scatter plot flips alpha order depending on depth relative to camera
* :ghissue:`29532`: [Bug]: ScalarFormatter can't be forced to use an offset of 1
* :ghissue:`16659`: Speeding up Axes3D.plot_surface 4-8x
* :ghissue:`29524`: [Doc]: Unclear how to compile ``c_internals`` in code space
* :ghissue:`29489`: [Bug]: Systematic test failures with ubuntu-22.04-arm pipeline
* :ghissue:`28915`: [Doc]: Preferred way of specifying colormaps via ``cmap``
* :ghissue:`29305`: [Doc]: Dead link in dev workflow docs
* :ghissue:`28763`: [MNT]: ListedColormap inconsistencies
* :ghissue:`29428`: [Doc]: Multipage PDF: unclear which backend supports and which does not support attach_note()
* :ghissue:`29387`: [MNT]: Fix 3.10 release notes and merge up
* :ghissue:`27321`: [Bug]: The method for checking whether a color has an alpha value is outdated
* :ghissue:`29284`: [Bug]: ``get_ticklabels``/``set_ticklabels`` gives incorrect values in log plot
* :ghissue:`26074`: [ENH]: Different edgecolor and hatch color in bar plot
* :ghissue:`29313`: [DOC]: possible typos
* :ghissue:`27763`: [Bug]: colorbar doesn't register inset_axis as cax
* :ghissue:`23770`: [Bug]: crash due to backend issue in ipython session started explicitly with InteractiveShell
* :ghissue:`19017`: Formalize discouraged API (= softer deprecations)
* :ghissue:`22521`: [Bug]: X-Axis date label not rotated
* :ghissue:`29181`: [Doc]: locally testing changes
* :ghissue:`17740`: Multiple Arrows on Streamplots
* :ghissue:`19101`: support for ticks crossing axes in axisartist
* :ghissue:`24050`: No error message in matplotlib.axes.Axes.legend() if there are more labels than handles
* :ghissue:`7305`: RuntimeError In FT2Font with NISC18030.ttf


Previous GitHub statistics
--------------------------

.. toctree::
    :maxdepth: 1
    :glob:
    :reversed:

    prev_whats_new/github_stats_*
